@@ -2,11 +2,11 @@
 #
 # Legal Stuff:
 #
-# This file is part of the Suru Icon Theme and is free software; you can redistribute it and/or modify it under
+# This file is part of the Yaru Icon Theme and is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free Software
 # Foundation; version 3.
 #
-# This file is part of the Suru Icon Theme and is distributed in the hope that it will be useful, but WITHOUT
+# This file is part of the Yaru Icon Theme and is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 # details.
@@ -25,7 +25,6 @@ import argparse
 
 
 OPTIPNG = "optipng"
-MAINDIR = "../../Suru"
 SOURCES = (
     "actions",
     "apps",
@@ -43,7 +42,7 @@ SOURCES = (
 DPIS = [1, 2]
 
 
-def main(args, SRC):
+def main(args, SRC, DEST):
     def optimize_png(png_file):
         if os.path.exists(OPTIPNG):
             process = subprocess.Popen([OPTIPNG, "-quiet", "-o7", png_file])
@@ -184,7 +183,7 @@ def main(args, SRC):
                         if dpi_factor != 1:
                             size_str += "@%sx" % dpi_factor
 
-                        dir = os.path.join(MAINDIR, size_str, self.context)
+                        dir = os.path.join(DEST, size_str, self.context)
                         outfile = os.path.join(dir, self.icon_name + ".png")
                         if not os.path.exists(dir):
                             os.makedirs(dir)
@@ -207,16 +206,18 @@ def main(args, SRC):
         def characters(self, chars):
             self.chars += chars.strip()
 
+    rendered_icons = 0
     if not args.svg:
         print("Rendering all SVGs in", SRC)
-        if not os.path.exists(MAINDIR):
-            os.mkdir(MAINDIR)
+        if not os.path.exists(DEST):
+            os.mkdir(DEST)
 
         for file in os.listdir(SRC):
             if file[-4:] == ".svg":
                 file = os.path.join(SRC, file)
                 handler = ContentHandler(file)
                 xml.sax.parse(open(file), handler)
+                rendered_icons += 1
         print("")
     else:
         svg = args.svg + ".svg"
@@ -226,6 +227,7 @@ def main(args, SRC):
             print('Rendering SVG "%s" in %s' % (svg, SRC))
             handler = ContentHandler(file, True, filter=args.filter)
             xml.sax.parse(open(file), handler)
+            rendered_icons += 1
         else:
             print(
                 'Could not find SVG "%s" in %s, looking into the next one' % (svg, SRC)
@@ -233,9 +235,35 @@ def main(args, SRC):
             # icon not in this directory, try the next one
             pass
 
+    return rendered_icons
+
 
 parser = argparse.ArgumentParser(description="Render icons from SVG to PNG")
 
+parser.add_argument(
+    '--source-path',
+    type=str,
+    default=None,
+    help='Path where to look for source svg files. Script path by default'
+)
+parser.add_argument(
+    '--dest-path',
+    type=str,
+    default=None,
+    help='Path where to save generated svg files. Script path by default'
+)
+parser.add_argument(
+    '--variant',
+    type=str,
+    default='default',
+    help='Variant name to render. If not given, render the default variant'
+)
+parser.add_argument(
+    '--categories',
+    type=str,
+    default=None,
+    help='Only look for icons in a specified categories'
+)
 parser.add_argument(
     "svg",
     type=str,
@@ -253,6 +281,21 @@ parser.add_argument(
 
 args = parser.parse_args()
 
+script_path = os.path.abspath(os.path.dirname(sys.argv[0]))
+source_path = args.source_path if args.source_path else script_path
+dest_path = args.dest_path if args.dest_path else os.path.join(script_path, '../../')
+rendered_icons = 0
+
 for source in SOURCES:
-    SRC = os.path.join(".", source)
-    main(args, SRC)
+    if args.categories and source not in args.categories:
+        continue
+
+    SRC = os.path.join(source_path, args.variant, source)
+    DEST = os.path.abspath(os.path.join(dest_path, "Yaru" if args.variant ==
+                                        'default' else "Yaru-" + args.variant))
+    if os.path.exists(SRC):
+        rendered_icons += main(args, SRC, DEST)
+
+if rendered_icons == 0:
+    print('No SVG found to render')
+    sys.exit(1)
