@@ -4,14 +4,18 @@
 ## usage:
 ##
 ## options:
-##     -a, --all                Optimize ALL the icons in icons/src/<context> [default:0]
-##     -c, --context <name>     Optimize ALL the icons in icons/src/<context> and save them under icons/Suru/<context>
-##     -f, --file <name>        Optimize only the icon in icons/src/<context>/<path> and save it under icons/Suru/<context>/<name> (needs --context)
+##     -a, --all                Optimize ALL the icons in icons/src/<variant> [default:0]
+##     -v, --variant <name>     Optimize the icons in icons/src/<variant> [default:default]
+##     -c, --context <name>     Optimize ALL the icons in icons/src/<variant>/<context> and save them under icons/Yaru/<context>
+##     -f, --file <name>        Optimize only the icon in icons/src/<variant>/<context>/<path> and save it under icons/Yaru/<context>/<name> (needs --context)
 ##
 ## NOTE:
-## contexts are: actions, apps, categories, devices, emblems, emotes, legacy, mimetypes, places, status, ui.
+## contexts are: actions, apps, camera, categories, devices, emblems, emotes, generic-symbols, legacy, mimetypes, multimedia, phosh, places, status, time, ui.
 
 # CLInt GENERATED_CODE: start
+# Default values
+_all=0
+_variant=default
 
 # No-arguments is not allowed
 [ $# -eq 0 ] && sed -ne 's/^## \(.*\)/\1/p' $0 && exit 1
@@ -21,7 +25,8 @@ for arg in "$@"; do
   shift
   case "$arg" in
 "--all") set -- "$@" "-a";;
-"--context") set -- "$@" "-g";;
+"--variant") set -- "$@" "-v";;
+"--context") set -- "$@" "-c";;
 "--file") set -- "$@" "-f";;
   *) set -- "$@" "$arg"
   esac
@@ -32,11 +37,12 @@ function print_illegal() {
 }
 
 # Parsing flags and arguments
-while getopts 'hac:f:' OPT; do
+while getopts 'hav:c:f:' OPT; do
     case $OPT in
         h) sed -ne 's/^## \(.*\)/\1/p' $0
            exit 1 ;;
         a) _all=1 ;;
+        v) _variant=$OPTARG ;;
         c) _context=$OPTARG ;;
         f) _file=$OPTARG ;;
         \?) print_illegal $@ >&2;
@@ -57,7 +63,7 @@ fatal() {
   exit 1
 }
 
-contexts=( actions apps categories devices emblems emotes legacy mimetypes places status ui )
+contexts=( actions apps camera categories devices emblems emotes generic-symbols legacy mimetypes multimedia phosh places status time ui )
 
 ###################################################
 # CHECKS
@@ -80,14 +86,21 @@ info "dependencies OK."
 # FUNCTIONS
 ###################################################
 optimize() {
-  GROUP=$1
-  NAME=$2
+  VARIANT=$1
+  GROUP=$2
+  NAME=$3
 
-  INPUT=${GROUP}/${NAME}
+  if [[ ${VARIANT} == "default" ]]; then
+    SUFFIX=""
+  else
+    SUFFIX=-${VARIANT}
+  fi
+
+  INPUT=${VARIANT}/${GROUP}/${NAME}
   [[ ! -f ${INPUT} ]] && fatal "could not find input file: ${INPUT}"
 
-  OUTDIR=../../Suru/scalable/${GROUP}/
-  OUTPUT=../../Suru/scalable/${GROUP}/${NAME}
+  OUTDIR=../../Yaru${SUFFIX}/scalable/${GROUP}/
+  OUTPUT=../../Yaru${SUFFIX}/scalable/${GROUP}/${NAME}
   [[ ! -d ${OUTDIR} ]] && fatal "could not find output directory: ${OUTDIR}"
 
   cmd="scour -i ${INPUT} -o ${OUTPUT} --enable-viewboxing --create-groups --shorten-ids --enable-id-stripping --enable-comment-stripping --disable-embed-rasters --remove-metadata --strip-xml-prolog"
@@ -102,18 +115,18 @@ optimize() {
 # render single file
 if [[ ! -z ${_file} ]]; then
   [[ -z ${_context} ]] && fatal "No icon context found! Please provide the icon context with --context."
-  info "rendering ${_context}/${_file}"
-  optimize $_context $_file
+  info "rendering ${_variant}/${_context}/${_file}"
+  optimize $_variant $_context $_file
   exit 0
 fi
 
 # render single context
 if [[ ! -z ${_context} ]]; then
-  count=$(ls ${_context} | wc -l)
+  count=$(ls ${_variant}/${_context} | wc -l)
   let i=1
-  for file in $(ls ${_context}); do
-    echo "[$i/$count] rendering ${_context}/${file}"
-    optimize $_context $file
+  for file in $(ls ${_variant}/${_context}); do
+    echo "[$i/$count] rendering ${_variant}/${_context}/${file}"
+    optimize $_variant $_context $file
     let i++
   done
   exit 0
@@ -122,14 +135,17 @@ fi
 # render all
 if [[ ! -z ${_all} ]]; then
   for context in "${contexts[@]}"; do
-    info "rendering context ${context}"
-    count=$(ls ${context} | wc -l)
-    let i=1
-    for file in $(ls ${context}); do
-      info "[$i/$count] rendering ${context}/${file}"
-      optimize $context $file
-      let i++
-    done
+    # If the variant is not the default one, check if context exist
+    if [[ ${VARIANT} == "default" || (${VARIANT} != "default" && -d "${_variant}/${context}") ]]; then
+      info "rendering context ${context} of ${_variant} variant"
+      count=$(ls ${_variant}/${context} | wc -l)
+      let i=1
+      for file in $(ls ${_variant}/${context}); do
+        info "[$i/$count] rendering ${_variant}/${context}/${file}"
+        optimize $_variant $context $file
+        let i++
+      done
+    fi
   done
   exit 0
 fi
